pub struct CCGameManager {
pub player_info: GDPlayerInfo,
pub stats: GDStatistics,
pub config: GDConfig,
pub account: GDAccount,
pub keybinds: (Dictionary, Dictionary),
pub temp_state: GDCurrentValues,
pub song_config: GDSongConfig,
pub other_properties: HashMap<String, Value>,
}Expand description
Container struct for the CCGameManager.dat file
Fields
player_info: GDPlayerInfoInfo about the player. Namely, selected icons
stats: GDStatisticsPlayer statistics stored in the file
config: GDConfigPlayer’s configuration of the game (e.g. volume, resolution, texture quality, etc.)
account: GDAccountAccount info
keybinds: (Dictionary, Dictionary)Keybindings descriptors. Not much is known about these.
Internal keys: KBM_001, KBM_002 respectively
temp_state: GDCurrentValuesTemporary state variables
song_config: GDSongConfigMDLM_001 and MDLM_002
other_properties: HashMap<String, Value>Unaccounted-for properties
Implementations
Sourceimpl CCGameManager
impl CCGameManager
Sourcepub fn from_local() -> Result<Self, GDError>
pub fn from_local() -> Result<Self, GDError>
Parses the local CCGameManager.dat file if it exists and is a valid file.
Sourcepub fn from_raw_string(s: String) -> Result<Self, GDError>
pub fn from_raw_string(s: String) -> Result<Self, GDError>
Parses a raw savefile plist to this object. The parser accounts for unknown keys, however it will panic in the case of a mistyped value.
For example, an achievement’s progress value not being a numeric utf-8 string will cause the parser to panic.
Please consider this when parsing possibly malformed savefiles.