pub struct GDSearchFilterFlags(/* private fields */);Expand description
Filters for searching online levels
Implementations
Sourceimpl GDSearchFilterFlags
impl GDSearchFilterFlags
Sourcepub const DifficultyNA: Self
pub const DifficultyNA: Self
Internal key: Diff0
Sourcepub const DifficultyAuto: Self
pub const DifficultyAuto: Self
Internal key: Diff1
Sourcepub const DifficultyEasy: Self
pub const DifficultyEasy: Self
Internal key: Diff2
Sourcepub const DifficultyNormal: Self
pub const DifficultyNormal: Self
Internal key: Diff3
Sourcepub const DifficultyHard: Self
pub const DifficultyHard: Self
Internal key: Diff4
Sourcepub const DifficultyHarder: Self
pub const DifficultyHarder: Self
Internal key: Diff5
Sourcepub const DifficultyInsane: Self
pub const DifficultyInsane: Self
Internal key: Diff6
Sourcepub const DifficultyDemon: Self
pub const DifficultyDemon: Self
Internal key: Diff7
Sourcepub const LengthTiny: Self
pub const LengthTiny: Self
Tiny levels
Internal key: Len0
Sourcepub const LengthSmall: Self
pub const LengthSmall: Self
Small levels
Internal key: Len1
Sourcepub const LengthMedium: Self
pub const LengthMedium: Self
Medium levels
Internal key: Len2
Sourcepub const LengthLong: Self
pub const LengthLong: Self
Long levels
Internal key: Len3
Sourcepub const DemonFilter: Self
pub const DemonFilter: Self
Internal key: demon_filter
Sourcepub const Platformer: Self
pub const Platformer: Self
Platformer levels
Internal key: Len5
Sourcepub const CustomSongFilter: Self
pub const CustomSongFilter: Self
Internal key: customsong_filter
Sourcepub const SongFilterEnabled: Self
pub const SongFilterEnabled: Self
Internal key: enable_songFilter
Sourcepub const IsUncompleted: Self
pub const IsUncompleted: Self
Works only for rated levels.
Internal key: uncompleted_filter
Sourcepub const IsCompleted: Self
pub const IsCompleted: Self
Internal key: completed_filter
Sourcepub const IsFeatured: Self
pub const IsFeatured: Self
Internal key: featured_filter
Sourcepub const IsOriginal: Self
pub const IsOriginal: Self
Internal key: original_filter
Sourcepub const FollowedCreator: Self
pub const FollowedCreator: Self
Levels from creators that the player follows.
Internal key: follow_filter
Sourcepub const RatingEpic: Self
pub const RatingEpic: Self
Levels with a rating of epic.
Internal key: epic_filter
Sourcepub const RatingLegendary: Self
pub const RatingLegendary: Self
Internal key: legendary_filter
Sourceimpl GDSearchFilterFlags
impl GDSearchFilterFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl GDSearchFilterFlags
impl GDSearchFilterFlags
Sourcepub const fn iter(&self) -> Iter<GDSearchFilterFlags>
pub const fn iter(&self) -> Iter<GDSearchFilterFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<GDSearchFilterFlags>
pub const fn iter_names(&self) -> IterNames<GDSearchFilterFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.