Module gdlevel

Module gdlevel 

This module contains the objects necessary for operations relating to the CCLocalLevels file, the Level struct, and its constituent structs.

Modules

enums
Enums present in GDLevel and GDList.
leveldata
This module conatins methods and structs for operations with individual levels

Structs

CCLocalLevels
Container struct for the CCLocalLevels savefile.
GDLevel
The descriptor struct for GD levels which contains all known properties.
GDLevelCoins
Data about the coins in the level
GDLevelContents
Values to do with the level data / gameplay. Notably, the level data itself, object count, length, etc.
GDLevelEditorState
Editor state variables for this level
GDLevelFlags
Various boolean flags for this level
GDLevelIdentity
Identity of the level and data surrounding it. Notably, the level name, id, and creator (among others).
GDLevelIntegrity
Variables that have to do with checking the integrity of the level’s integrity
GDLevelMeta
Miscellaneous metadata surrounding the level. Mostly internal or organizational fields.
GDLevelPlayerStats
Player’s statistics on this level, notably, attempts.
GDLevelRatings
Rating data about a level (e.g. star rating, likes, downloads)
GDLevelUnknowns
Keys that are undocumented or have no known purpose.

Constants

PLIST_FOOTER
Standard footer of a GD plist.
PLIST_HEADER
Standard header of a GD plist.