OfficialSong

Enum OfficialSong 

pub enum OfficialSong {
Show 42 variants StayInsideMe, StereoMadness, BackOnTrack, Polargeist, DryOut, BaseAfterBase, CantLetGo, Jumper, TimeMachine, Cycles, Xstep, Clutterfunk, TheoryOfEverything, ElectromanAdventures, Clubstep, Electrodynamix, HexagonForce, BlastProcessing, TheoryOfEverything2, GeometricalDominator, Deadlocked, Fingerdash, Dash, Explorers, TheSevenSeas, VikingArena, AirborneRobots, Secret, Payload, BeastMode, Machina, Years, Frontlines, SpacePirates, Striker, Embers, Round1, MonsterDanceOff, PressStart, NockEm, PowerTrip, Unrecognized(i32),
}
All official songs used in GD, including in spin-off games.

Variants



StayInsideMe



StereoMadness



BackOnTrack



Polargeist



DryOut



BaseAfterBase



CantLetGo



Jumper



TimeMachine



Cycles



Xstep



Clutterfunk



TheoryOfEverything



ElectromanAdventures



Clubstep



Electrodynamix



HexagonForce



BlastProcessing



TheoryOfEverything2



GeometricalDominator



Deadlocked



Fingerdash



Dash



Explorers



TheSevenSeas



VikingArena



AirborneRobots



Secret



Payload



BeastMode



Machina



Years



Frontlines



SpacePirates



Striker



Embers



Round1



MonsterDanceOff



PressStart



NockEm



PowerTrip



Unrecognized(i32)

Value that is unaccounted for (unknown case or corrupt value)

Implementations

Source

impl OfficialSong

pub fn to_num(&self) -> i32

Converts self to its numeric type. Autogenerated by the crate::repr_t macro.

Normally, #[repr(t)] would be used here as that would serve as the same thing. However, for cases where a value may be parsed that isn’t accounted for, an Unrecognized variant is necessary, which allows us to catch “other” values.