ColourString

Struct ColourString 

pub struct ColourString {
Show 14 fields pub from: Colour, pub to: Colour, pub player_colour: PlayerColour, pub blending: bool, pub colour_ch_idx: i32, pub from_opacity: f32, pub to_opacity: f32, pub opacity_toggled: bool, pub inherited_col_ch_idx: i32, pub copied_hsv: Option<HSVColour>, pub deltatime: f32, pub duration: f32, pub copy_opacity: bool, pub unknown_property18: bool,
}
Descriptor struct for the colour string.

Reference: https://boomlings.dev/resources/client/level-components/color-string

Fields

from: Colour

The colour itself

to: Colour

What this colour changes to

player_colour: PlayerColour

Player colour that is being copied by this colour

blending: bool

Using blending

colour_ch_idx: i32

This colour’s channel index

from_opacity: f32

Opacity of this colour

to_opacity: f32

What opacity this colour becomes

opacity_toggled: bool

Toggles changing opacity

inherited_col_ch_idx: i32

The channel index that this colour inherits (if any)

copied_hsv: Option<HSVColour>

HSV of the copied colour

deltatime: f32

Delta used to change colour

duration: f32

Time of transiton from from colour to to colour

copy_opacity: bool

@nodoc

unknown_property18: bool

Unknown property with index 18

Implementations

Source

impl ColourString

pub fn parse(s: &str) -> Option<Self>

Parses a colour string segment into this object

pub fn to_string(&self) -> String

Serialises this object to a String.