GDLevelEditorState

Struct GDLevelEditorState 

pub struct GDLevelEditorState {
    pub camera_x: f32,
    pub camera_y: f32,
    pub camera_zoom: f32,
    pub build_tab_page: i32,
    pub build_tab: i32,
    pub build_tab_pages: SmallVec<[i32; 16]>,
    pub editor_layer: f32,
}
Editor state variables for this level

Fields

camera_x: f32

Internal key: kI1

camera_y: f32

Internal key: kI2

camera_zoom: f32

Internal key: kI3

build_tab_page: i32

Internal key: kI4

build_tab: i32

Internal key: kI5

build_tab_pages: SmallVec<[i32; 16]>

A list of indices for each editor tab that describes where the user is currently. For example, build_tab_pages[0] is the page of the first tab that the user was last in.

Internal key: kI6

editor_layer: f32

Internal key: kI7