state_block

Function state_block 

pub fn state_block(
    config: &GDObjConfig,
    state_on: i16,
    state_off: i16,
) -> GDObject
Returns a state block object

Arguments

  • config: General object options, such as position and scale
  • state_on: Group that is activated when the player enters this block’s hitbox
  • state_off: Group that is activated when the player exits this block’s hitbox