Module structs

Module structs 

This module contains all structs and enums for values that are present in GD objects.

Modules

animation_ids

Structs

ColliderConfig
Configuration struct for collide triggers which specifies the colliders that are checked for collisions.
Colour
RGB colour tuple
ColourTriggerConfig
Configuration struct for the primary colour operation in a colour trigger
CompareOperand
Compare operand configuration specifier for the item control trigger
CopyColourConfig
Config struct for copy colour options
DefaultMove
Config struct for default movement
DirectionalMove
Config struct for moving to a specific target.
HSVColour
Config struct for HSV colour settings
ParticleSpawnConfig
Configuration descriptor for spawning particles in particle spawn trigger
PulseChannel
Config struct for channel pulses
PulseGroup
Config struct for group pulses
PulseHSV
Pulse with HSV mode configuration
RotationAim
Config struct for aim mode rotation
RotationConfig
Struct for specifying rotation settings in a rotate trigger
RotationNormal
Degree amount rotation specifier
ScaleConfig
Configuration struct for scaling of objects in the scale trigger
StartposConfig
Gameplay starting settings specification struct for the startpos trigger
TargetMove
Config struct for moving to a specific target.
TimeTriggerConfig
Configuration struct for the time trigger

Enums

Anim
Enum for animation IDs
AxisOnlyMove
Optional axis lock for move triggers
ColourChannel
Enum for colour channels and their IDs
CompareOp
Enum for item comparison operators
CounterMode
Enum for counter modes
Event
Enum for all events that the event trigger can listen for
ExtraID2
Extra ID 2 parameter in the event trigger
GDObjPropType
Corresponding types for GDValues.
GDValue
Enum for all values represented by Geometry Dash. All values are parsed according to their specified GDObjPropType.
Gamemode
Enum for the GD gamemodes corresponding to their internal values
Group
Group ID container for regular and parent groups
GroupType
Group type enum
Item
In-level value container. Used in such triggers as item edit, item compare and item persisent
ItemAlign
Enum for item alignments
ItemType
Enum for counter types
MiddleGround
Enum for middle grounds
MoveEasing
Enum for all of the move easings
MoveLock
Enum for lock config: player or camera
MoveMode
Enum for move mode setting. See structs DefaultMove, TargetMove, and DirectionalMove
MoveTarget
Enum for move targets.
Op
Enum for item operators
OptionalPlayerTarget
Enum for an optional player target. Used in the touch trigger
PulseMode
Enum for pulse mode
PulseTarget
Enum for target of pulse
RotationMode
Enum for rotation configs
RotationPlayerTarget
Optional target of rotation
RoundMode
Enum for item round modes
SignMode
Enum for item sign modes
Speed
Enum for starting speed in a startpos
StopMode
Enum for stop trigger modes
TargetPlayer
Enum for target player in gravity trigger
TouchToggle
Enum for modes of activation in a touch trigger
TransitionMode
Enum for transition object enter/exit config
TransitionType
Enum for transition object type (from top, from bottom, etc.)
UIReferencePos
Enum for relative UI reference position
ZLayer