pub enum MoveMode {
Default(DefaultMove),
Targeting(TargetMove),
Directional(DirectionalMove),
}Expand description
Enum for move mode setting. See structs DefaultMove, TargetMove, and DirectionalMove
Variants
Default(DefaultMove)
Normal axis-based move mode
Targeting(TargetMove)
Moves the group to the position of another group
Directional(DirectionalMove)
Moves the group in the direction of another group