pub struct DefaultMove {
pub dx: f64,
pub dy: f64,
pub x_lock: Option<MoveLock>,
pub y_lock: Option<MoveLock>,
}Expand description
Config struct for default movement
Fields
dx: f64Units to move in x-axis. Used as multiplier of player/camera movement if x_lock is used
dy: f64Units to move in y-axis. Used as multiplier of player/camera movement if y_lock is used
x_lock: Option<MoveLock>Optional lock on x movement which allows the object to move relative to either the player or the camera
y_lock: Option<MoveLock>Optional lock on y movement which allows the object to move relative to either the player or the camera