This module contains the objects necessary for operations relating to the CCLocalLevels file, the Level struct, and its constituent structs.
Modules
- enums
- Enums present in GDLevel and GDList.
- leveldata
- This module conatins methods and structs for operations with individual levels
Structs
- CCLocal
Levels - Container struct for the CCLocalLevels savefile.
- GDLevel
- The descriptor struct for GD levels which contains all known properties.
- GDLevel
Coins - Data about the coins in the level
- GDLevel
Contents - Values to do with the level data / gameplay. Notably, the level data itself, object count, length, etc.
- GDLevel
Editor State - Editor state variables for this level
- GDLevel
Flags - Various boolean flags for this level
- GDLevel
Identity - Identity of the level and data surrounding it. Notably, the level name, id, and creator (among others).
- GDLevel
Integrity - Variables that have to do with checking the integrity of the level’s integrity
- GDLevel
Meta - Miscellaneous metadata surrounding the level. Mostly internal or organizational fields.
- GDLevel
Player Stats - Player’s statistics on this level, notably, attempts.
- GDLevel
Ratings - Rating data about a level (e.g. star rating, likes, downloads)
- GDLevel
Unknowns - Keys that are undocumented or have no known purpose.
Constants
- PLIST_
FOOTER - Standard footer of a GD plist.
- PLIST_
HEADER - Standard header of a GD plist.