pub struct ColourString {Show 14 fields
pub from: Colour,
pub to: Colour,
pub player_colour: PlayerColour,
pub blending: bool,
pub colour_ch_idx: i32,
pub from_opacity: f32,
pub to_opacity: f32,
pub opacity_toggled: bool,
pub inherited_col_ch_idx: i32,
pub copied_hsv: Option<HSVColour>,
pub deltatime: f32,
pub duration: f32,
pub copy_opacity: bool,
pub unknown_property18: bool,
}Expand description
Descriptor struct for the colour string.
Reference: https://boomlings.dev/resources/client/level-components/color-string
Fields
from: ColourThe colour itself
to: ColourWhat this colour changes to
player_colour: PlayerColourPlayer colour that is being copied by this colour
blending: boolUsing blending
colour_ch_idx: i32This colour’s channel index
from_opacity: f32Opacity of this colour
to_opacity: f32What opacity this colour becomes
opacity_toggled: boolToggles changing opacity
inherited_col_ch_idx: i32The channel index that this colour inherits (if any)
copied_hsv: Option<HSVColour>HSV of the copied colour
deltatime: f32Delta used to change colour
duration: f32Time of transiton from from colour to to colour
copy_opacity: bool@nodoc
unknown_property18: boolUnknown property with index 18
Implementations