pub struct GDLevelIdentity {Show 15 fields
pub id: i32,
pub name: String,
pub description: Option<String>,
pub creator: String,
pub user_id: i32,
pub account_id: i32,
pub level_version: i32,
pub level_revision: Option<i32>,
pub game_version: i32,
pub build_version: i32,
pub binary_version: i32,
pub level_type: GDLevelType,
pub timely_id: i32,
pub original_id: Option<i32>,
pub password: Option<i32>,
}Expand description
Identity of the level and data surrounding it. Notably, the level name, id, and creator (among others).
Fields
id: i32Internal key: k1
name: StringInternal key: k2
description: Option<String>Internal key: k3
creator: StringUsername of the creator.
Internal key: k5
user_id: i32User ID of the creator.
Internal key: k6
account_id: i32Account ID of the creator.
Internal key: k60
level_version: i32Internal key: k16
level_revision: Option<i32>Internal key: k46
game_version: i32Version of the game that this level was created on.
Internal key: k17
build_version: i32Internal key: k40
binary_version: i32Hardcoded value. LLM_02 is also hardcoded to this value.
Internal key: k50
level_type: GDLevelTypeType of this level: GDLevelType
Internal key: k21
timely_id: i32ID of the daily/weekly/event level.
Internal key: k74
original_id: Option<i32>Original ID of the level this one was copied from
Internal key: k42
password: Option<i32>Password to copy the level
Internal key: k41